@@ -8,7 +8,6 @@
 #include "customtoolsplugin.h"
 
 #include <KPluginFactory>
-#include <KPluginLoader>
 #include <KPluginMetaData>
 
 #include <QDebug>
@@ -56,7 +55,7 @@ public:
 
 void CustomToolsPluginManagerPrivate::initializePluginList()
 {
-    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("pimcommon/customtools"));
+    const QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("pimcommon/customtools"));
 
     QVectorIterator<KPluginMetaData> i(plugins);
     i.toBack();
@@ -96,9 +95,8 @@ QVector<PimCommon::CustomToolsPlugin *> CustomToolsPluginManagerPrivate::plugins
 
 void CustomToolsPluginManagerPrivate::loadPlugin(CustomToolsPluginInfo *item)
 {
-    KPluginLoader pluginLoader(item->metaData.fileName());
-    if (pluginLoader.factory()) {
-        item->plugin = pluginLoader.factory()->create<PimCommon::CustomToolsPlugin>(q, QVariantList() << item->saveName());
+    if (auto plugin = KPluginFactory::instantiatePlugin<PimCommon::CustomToolsPlugin>(item->metaData, q, QVariantList() << item->saveName()).plugin) {
+        item->plugin = plugin;
     }
 }
 
@@ -115,10 +113,7 @@ CustomToolsPluginManager::CustomToolsPluginManager(QObject *parent)
     d->initializePluginList();
 }
 
-CustomToolsPluginManager::~CustomToolsPluginManager()
-{
-    delete d;
-}
+CustomToolsPluginManager::~CustomToolsPluginManager() = default;
 
 QVector<PimCommon::CustomToolsPlugin *> CustomToolsPluginManager::pluginsList() const
 {
