@@ -4,10 +4,10 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef AbstractGENERICPLUGININTERFACE_H
-#define AbstractGENERICPLUGININTERFACE_H
+#pragma once
 #include "pimcommon_export.h"
 #include <QObject>
+#include <memory>
 class QAction;
 class KActionCollection;
 namespace PimCommon
@@ -41,7 +41,7 @@ class PIMCOMMON_EXPORT AbstractGenericPluginInterface : public QObject
     Q_OBJECT
 public:
     explicit AbstractGenericPluginInterface(QObject *parent = nullptr);
-    ~AbstractGenericPluginInterface();
+    ~AbstractGenericPluginInterface() override;
 
     void setParentWidget(QWidget *parent);
     Q_REQUIRED_RESULT QWidget *parentWidget() const;
@@ -59,7 +59,6 @@ Q_SIGNALS:
     void message(const QString &str);
 
 private:
-    AbstractGenericPluginInterfacePrivate *const d;
+    std::unique_ptr<AbstractGenericPluginInterfacePrivate> const d;
 };
 }
-#endif // AbstractGENERICPLUGININTERFACE_H
