@@ -4,8 +4,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef LINEEDITWITHCOMPLETERNG_H
-#define LINEEDITWITHCOMPLETERNG_H
+#pragma once
 
 #include "pimcommon_export.h"
 #include <QLineEdit>
@@ -32,8 +31,7 @@ public Q_SLOTS:
     void slotClearHistory();
 
 private:
-    QStringListModel *mCompleterListModel = nullptr;
+    QStringListModel *const mCompleterListModel;
     QStringList mListCompetion;
 };
 }
-#endif // LINEEDITWITHCOMPLETER_H
