@@ -15,6 +15,7 @@
 #include <KLDAP/LdapSearchClientReadConfigServerJob>
 #include <Libkdepim/LineEditCatchReturnKey>
 #include <Libkdepim/ProgressIndicatorLabel>
+#include <kcontacts_version.h>
 
 #include <QApplication>
 #include <QCheckBox>
@@ -36,6 +37,7 @@
 #include <KConfig>
 #include <KConfigGroup>
 #include <KMessageBox>
+#include <KPluginMetaData>
 #include <QComboBox>
 #include <QDialogButtonBox>
 #include <QLineEdit>
@@ -68,14 +70,14 @@ static QString asUtf8(const QByteArray &val)
 static QString join(const KLDAP::LdapAttrValue &lst, const QString &sep)
 {
     QString res;
-    bool alredy = false;
+    bool already = false;
     KLDAP::LdapAttrValue::ConstIterator end(lst.constEnd());
     for (KLDAP::LdapAttrValue::ConstIterator it = lst.constBegin(); it != end; ++it) {
-        if (alredy) {
+        if (already) {
             res += sep;
         }
 
-        alredy = true;
+        already = true;
         res += asUtf8(*it);
     }
 
@@ -160,7 +162,13 @@ static KContacts::Addressee convertLdapAttributesToAddressee(const KLDAP::LdapAt
     KLDAP::LdapAttrValue::ConstIterator it = lst.constBegin();
     bool pref = true;
     while (it != lst.constEnd()) {
+#if KContacts_VERSION < QT_VERSION_CHECK(5, 88, 0)
         addr.insertEmail(asUtf8(*it), pref);
+#else
+        KContacts::Email email(asUtf8(*it));
+        email.setPreferred(pref);
+        addr.addEmail(email);
+#endif
         pref = false;
         ++it;
     }
@@ -403,10 +411,10 @@ private:
     QStringList mServerList;
 };
 
-class Q_DECL_HIDDEN LdapSearchDialog::Private
+class Q_DECL_HIDDEN LdapSearchDialog::LdapSearchDialogPrivate
 {
 public:
-    Private(LdapSearchDialog *qq)
+    LdapSearchDialogPrivate(LdapSearchDialog *qq)
         : q(qq)
     {
     }
@@ -463,7 +471,7 @@ public:
 
 LdapSearchDialog::LdapSearchDialog(QWidget *parent)
     : QDialog(parent)
-    , d(new Private(this))
+    , d(new LdapSearchDialogPrivate(this))
 {
     setWindowTitle(i18nc("@title:window", "Import Contacts from LDAP"));
     auto mainLayout = new QVBoxLayout(this);
@@ -486,7 +494,7 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
     mainLayout->addWidget(buttonBox);
 
     auto topLayout = new QVBoxLayout(page);
-    topLayout->setContentsMargins(0, 0, 0, 0);
+    topLayout->setContentsMargins({});
 
     auto groupBox = new QGroupBox(i18n("Search for Addresses in Directory"), page);
     auto boxLayout = new QGridLayout();
@@ -561,7 +569,7 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
     d->mResultView->verticalHeader()->hide();
     d->mResultView->setSortingEnabled(true);
     d->mResultView->horizontalHeader()->setSortIndicatorShown(true);
-    connect(d->mResultView, qOverload<const QModelIndex &>(&QTableView::clicked), this, [this]() {
+    connect(d->mResultView, &QTableView::clicked, this, [this]() {
         d->slotSelectionChanged();
     });
     topLayout->addWidget(d->mResultView);
@@ -570,7 +578,7 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
     connect(d->mResultView, &QTableView::customContextMenuRequested, this, &LdapSearchDialog::slotCustomContextMenuRequested);
 
     auto buttonLayout = new QHBoxLayout;
-    buttonLayout->setContentsMargins(0, 0, 0, 0);
+    buttonLayout->setContentsMargins({});
     topLayout->addLayout(buttonLayout);
 
     d->progressIndication = new KPIM::ProgressIndicatorLabel(i18n("Searching..."));
@@ -607,7 +615,6 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
 LdapSearchDialog::~LdapSearchDialog()
 {
     d->saveSettings();
-    delete d;
 }
 
 void LdapSearchDialog::setSearchText(const QString &text)
@@ -633,12 +640,12 @@ void LdapSearchDialog::slotCustomContextMenuRequested(const QPoint &pos)
     }
 }
 
-void LdapSearchDialog::Private::slotSelectionChanged()
+void LdapSearchDialog::LdapSearchDialogPrivate::slotSelectionChanged()
 {
     user1Button->setEnabled(mResultView->selectionModel()->hasSelection());
 }
 
-void LdapSearchDialog::Private::restoreSettings()
+void LdapSearchDialog::LdapSearchDialogPrivate::restoreSettings()
 {
     // Create one KLDAP::LdapClient per selected server and configure it.
 
@@ -678,7 +685,9 @@ void LdapSearchDialog::Private::restoreSettings()
 
             ldapClient->setAttributes(attrs);
 
-            q->connect(ldapClient, SIGNAL(result(KLDAP::LdapClient, KLDAP::LdapObject)), q, SLOT(slotAddResult(KLDAP::LdapClient, KLDAP::LdapObject)));
+            // clang-format off
+            q->connect(ldapClient, SIGNAL(result(KLDAP::LdapClient,KLDAP::LdapObject)), q, SLOT(slotAddResult(KLDAP::LdapClient,KLDAP::LdapObject)));
+            // clang-format on
             q->connect(ldapClient, SIGNAL(done()), q, SLOT(slotSearchDone()));
             q->connect(ldapClient, &KLDAP::LdapClient::error, q, [this](const QString &err) {
                 slotError(err);
@@ -702,7 +711,7 @@ void LdapSearchDialog::Private::restoreSettings()
     }
 }
 
-void LdapSearchDialog::Private::saveSettings()
+void LdapSearchDialog::LdapSearchDialogPrivate::saveSettings()
 {
     KConfig *config = KLDAP::LdapClientSearchConfig::config();
     KConfigGroup group(config, "LDAPSearch");
@@ -719,19 +728,19 @@ void LdapSearchDialog::Private::saveSettings()
     group.sync();
 }
 
-void LdapSearchDialog::Private::cancelQuery()
+void LdapSearchDialog::LdapSearchDialogPrivate::cancelQuery()
 {
     for (KLDAP::LdapClient *client : std::as_const(mLdapClientList)) {
         client->cancelQuery();
     }
 }
 
-void LdapSearchDialog::Private::slotAddResult(const KLDAP::LdapClient &client, const KLDAP::LdapObject &obj)
+void LdapSearchDialog::LdapSearchDialogPrivate::slotAddResult(const KLDAP::LdapClient &client, const KLDAP::LdapObject &obj)
 {
     mModel->addContact(obj.attributes(), client.server().host());
 }
 
-void LdapSearchDialog::Private::slotSetScope(bool rec)
+void LdapSearchDialog::LdapSearchDialogPrivate::slotSetScope(bool rec)
 {
     for (KLDAP::LdapClient *client : std::as_const(mLdapClientList)) {
         if (rec) {
@@ -742,7 +751,7 @@ void LdapSearchDialog::Private::slotSetScope(bool rec)
     }
 }
 
-void LdapSearchDialog::Private::slotStartSearch()
+void LdapSearchDialog::LdapSearchDialogPrivate::slotStartSearch()
 {
     cancelQuery();
 
@@ -774,13 +783,13 @@ void LdapSearchDialog::Private::slotStartSearch()
     saveSettings();
 }
 
-void LdapSearchDialog::Private::slotStopSearch()
+void LdapSearchDialog::LdapSearchDialogPrivate::slotStopSearch()
 {
     cancelQuery();
     slotSearchDone();
 }
 
-void LdapSearchDialog::Private::slotSearchDone()
+void LdapSearchDialog::LdapSearchDialogPrivate::slotSearchDone()
 {
     // If there are no more active clients, we are done.
     for (KLDAP::LdapClient *client : std::as_const(mLdapClientList)) {
@@ -799,7 +808,7 @@ void LdapSearchDialog::Private::slotSearchDone()
 #endif
 }
 
-void LdapSearchDialog::Private::slotError(const QString &error)
+void LdapSearchDialog::LdapSearchDialogPrivate::slotError(const QString &error)
 {
 #ifndef QT_NO_CURSOR
     QApplication::restoreOverrideCursor();
@@ -813,13 +822,13 @@ void LdapSearchDialog::closeEvent(QCloseEvent *e)
     e->accept();
 }
 
-void LdapSearchDialog::Private::slotUnselectAll()
+void LdapSearchDialog::LdapSearchDialogPrivate::slotUnselectAll()
 {
     mResultView->clearSelection();
     slotSelectionChanged();
 }
 
-void LdapSearchDialog::Private::slotSelectAll()
+void LdapSearchDialog::LdapSearchDialogPrivate::slotSelectAll()
 {
     mResultView->selectAll();
     slotSelectionChanged();
@@ -861,7 +870,7 @@ void LdapSearchDialog::slotUser2()
 
     QPointer<KCMultiDialog> dialog = new KCMultiDialog(this);
     dialog->setWindowTitle(i18nc("@title:window", "Configure the Address Book LDAP Settings"));
-    dialog->addModule(QStringLiteral("kcmldap.desktop"));
+    dialog->addModule(KPluginMetaData(QStringLiteral("pim/kcms/kaddressbook/kcm_ldap")));
 
     if (dialog->exec()) { // krazy:exclude=crashy
         d->restoreSettings();
